cattbl
===========

Python modules for working in pandas with various loss data tables used for CAT modelling


## Installation

I use a virtual environment. You can see requirements in the file `requirements.txt`

You can install locally with

```
python setup.py install
```

## Modules
Best in python if you do
```
import cattbl
help(cattbl)
```
Then help on each module.

...documentation will be incomplete but more up-to-date than here.


## Versions
### v0.2.0
Introduction of base class
### v0.1.1
Removed the "t" from accessor names, i.e. changed names of accessors to yel and yl
### v0.1.0
Changed names of modules to yearevent and yeareventloss because often yelt, ylt 
are used as vairable names.
### v0.0.0 
First version with modules as ylt and yelt
